# -*- coding: utf-8 -*-
import swapper
from rest_framework import serializers
from thx.address.api.version1.serializers import AddressScopeLightSerializer
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)

from ... import models

Contact = swapper.load_model('organization', 'Contact')
Organization = swapper.load_model('organization', 'Organization')


# ORGANIZATION ADDRESS
class OrganizationAddressSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_address'
        model = models.OrganizationAddress
        fields = '__all__'


class OrganizationAddressListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    address_scopes = AddressScopeLightSerializer(many=True, read_only=True)
    country_name = serializers.CharField(source='country.name')

    class Meta:
        ref_name = 'v1_organization_organization_address_list'
        model = models.OrganizationAddress
        fields = (
            'id', 'status', 'status_display', 'organization', 'organization_name', 'org_name',
            'address_type', 'get_address_type_display', 'address_scopes',
            'name', 'number', 'zip_code', 'locality', 'province', 'country', 'country_name', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationAddressRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    address_scopes = AddressScopeLightSerializer(many=True, read_only=True)
    country_name = serializers.CharField(source='country.name')

    class Meta:
        ref_name = 'v1_organization_organization_address_retrieve'
        model = models.OrganizationAddress
        fields = (
            'id', 'status', 'status_display', 'organization', 'organization_name', 'org_name',
            'address_type', 'get_address_type_display', 'address_scopes', 'name', 'number',
            'zip_code', 'locality', 'province', 'country', 'country_name', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationAddressCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_address_create'
        model = models.OrganizationAddress
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationAddressRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationAddressUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_address_update'
        model = models.OrganizationAddress
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationAddressRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationAddressPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_address_partial_update'
        model = models.OrganizationAddress
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationAddressRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationAddressEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_address_enable'
        model = models.OrganizationAddress
        fields = ()
        response_serializer = OrganizationAddressRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationAddressDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_address_disable'
        model = models.OrganizationAddress
        fields = ()
        response_serializer = OrganizationAddressRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationAddressLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    country_name = serializers.CharField(source='country.name')

    class Meta:
        ref_name = 'v1_organization_organization_address_light'
        model = models.OrganizationAddress
        fields = (
            'id', 'status', 'status_display', 'organization_name', 'org_name', 'address_type', 'name', 'number',
            'zip_code', 'locality', 'province', 'country_name', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# EMAIL TYPOLOGY
class EmailTypologySerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology'
        model = models.EmailTypology
        fields = '__all__'


class EmailTypologyListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_list'
        model = models.EmailTypology
        fields = ('id', 'status', 'status_display', 'code', 'name', 'slug', 'ordering')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class EmailTypologyRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_retrieve'
        model = models.EmailTypology
        fields = ('id', 'status', 'status_display', 'code', 'name', 'slug', 'ordering')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class EmailTypologyCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_create'
        model = models.EmailTypology
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = EmailTypologyRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class EmailTypologyUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_update'
        model = models.EmailTypology
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = EmailTypologyRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class EmailTypologyPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_partial_update'
        model = models.EmailTypology
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = EmailTypologyRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class EmailTypologyEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_enable'
        model = models.EmailTypology
        fields = ()
        response_serializer = EmailTypologyRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class EmailTypologyDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_disable'
        model = models.EmailTypology
        fields = ()
        response_serializer = EmailTypologyRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class EmailTypologyLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_email_typology_light'
        model = models.EmailTypology
        fields = ('id', 'status', 'status_display', 'name',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# PHONE TYPOLOGY
class PhoneTypologySerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology'
        model = models.PhoneTypology
        fields = '__all__'


class PhoneTypologyListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_list'
        model = models.PhoneTypology
        fields = ('id', 'status', 'status_display', 'code', 'name', 'slug', 'ordering')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class PhoneTypologyRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_retrieve'
        model = models.PhoneTypology
        fields = ('id', 'status', 'status_display', 'code', 'name', 'slug', 'ordering')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class PhoneTypologyCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_create'
        model = models.PhoneTypology
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = PhoneTypologyRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class PhoneTypologyUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_update'
        model = models.PhoneTypology
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = PhoneTypologyRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class PhoneTypologyPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_partial_update'
        model = models.PhoneTypology
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = PhoneTypologyRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class PhoneTypologyEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_enable'
        model = models.PhoneTypology
        fields = ()
        response_serializer = PhoneTypologyRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class PhoneTypologyDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_disable'
        model = models.PhoneTypology
        fields = ()
        response_serializer = PhoneTypologyRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class PhoneTypologyLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_phone_typology_light'
        model = models.PhoneTypology
        fields = ('id', 'status', 'status_display', 'name',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# ORGANIZATION TYPE
class OrganizationTypeSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type'
        model = models.OrganizationType
        fields = '__all__'


class OrganizationTypeListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_list'
        model = models.OrganizationType
        fields = ('id', 'status', 'status_display', 'code', 'name', 'category', 'get_category_display', 'ordering',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationTypeRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_retrieve'
        model = models.OrganizationType
        fields = ('id', 'status', 'status_display', 'code', 'name', 'category', 'get_category_display', 'ordering',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationTypeCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_create'
        model = models.OrganizationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationTypeRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationTypeUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_update'
        model = models.OrganizationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationTypeRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationTypePartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_partial_update'
        model = models.OrganizationType
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationTypeRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationTypeEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_enable'
        model = models.OrganizationType
        fields = ()
        response_serializer = OrganizationTypeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationTypeDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_disable'
        model = models.OrganizationType
        fields = ()
        response_serializer = OrganizationTypeRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationTypeLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_type_light'
        model = models.OrganizationType
        fields = ('id', 'status', 'status_display', 'name',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# ORGANIZATION FORM
class OrganizationFormSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form'
        model = models.OrganizationForm
        fields = '__all__'


class OrganizationFormListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_list'
        model = models.OrganizationForm
        fields = ('id', 'status', 'status_display', 'code', 'name', 'ordering')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationFormRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_retrieve'
        model = models.OrganizationForm
        fields = ('id', 'status', 'status_display', 'code', 'name', 'ordering')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationFormCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_create'
        model = models.OrganizationForm
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationFormRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationFormUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_update'
        model = models.OrganizationForm
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationFormRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationFormPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_partial_update'
        model = models.OrganizationForm
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationFormRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationFormEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_enable'
        model = models.OrganizationForm
        fields = ()
        response_serializer = OrganizationFormRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationFormDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_disable'
        model = models.OrganizationForm
        fields = ()
        response_serializer = OrganizationFormRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationFormLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_form_light'
        model = models.OrganizationForm
        fields = ('id', 'status', 'status_display', 'name',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# ORGANIZATION
class OrganizationSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization'
        model = Organization
        fields = '__all__'


class OrganizationListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_list'
        model = Organization
        fields = (
            'id', 'status', 'status_display', 'category', 'organization_type', 'organization_type_name',
            'code', 'name', 'organization_form', 'organization_form_name', 'vat_number', 'ssn', 'email',
            'url', 'phone', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_retrieve'
        model = Organization
        fields = (
            'id', 'status', 'status_display', 'category', 'organization_type', 'organization_type_name',
            'code', 'name', 'brand', 'organization_form', 'organization_form_name', 'vat_number', 'ssn', 'email',
            'url', 'phone', 'phone2', 'note', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_create'
        model = Organization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_update'
        model = Organization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_partial_update'
        model = Organization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_enable'
        model = Organization
        fields = ()
        response_serializer = OrganizationRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_disable'
        model = Organization
        fields = ()
        response_serializer = OrganizationRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_light'
        model = Organization
        fields = ('id', 'status', 'status_display', 'name',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# OWNER ORGANIZATION
class OwnerOrganizationSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization'
        model = models.OwnerOrganization
        fields = '__all__'


class OwnerOrganizationListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_list'
        model = models.OwnerOrganization
        fields = (
            'id', 'status', 'status_display', 'category', 'organization_type', 'organization_type_name',
            'code', 'name', 'organization_form', 'organization_form_name', 'vat_number', 'ssn', 'email',
            'url', 'phone', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OwnerOrganizationRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_retrieve'
        model = models.OwnerOrganization
        fields = (
            'id', 'status', 'status_display', 'category', 'organization_type', 'organization_type_name',
            'code', 'name', 'brand', 'organization_form', 'organization_form_name', 'vat_number', 'ssn', 'email',
            'url', 'phone', 'phone2', 'note', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OwnerOrganizationCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_create'
        model = models.OwnerOrganization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OwnerOrganizationRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OwnerOrganizationUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_update'
        model = models.OwnerOrganization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OwnerOrganizationRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OwnerOrganizationPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_partial_update'
        model = models.OwnerOrganization
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OwnerOrganizationRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OwnerOrganizationEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_enable'
        model = models.OwnerOrganization
        fields = ()
        response_serializer = OwnerOrganizationRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OwnerOrganizationDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_disable'
        model = models.OwnerOrganization
        fields = ()
        response_serializer = OwnerOrganizationRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OwnerOrganizationLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_organization_light'
        model = models.OwnerOrganization
        fields = ('id', 'status', 'status_display', 'name',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# ORGANIZATION EMAIL
class OrganizationEmailSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email'
        model = models.OrganizationEmail
        fields = '__all__'


class OrganizationEmailListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_list'
        model = models.OrganizationEmail
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name', 'organization', 'organization_name',
            'email', 'is_primary', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationEmailRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_retrieve'
        model = models.OrganizationEmail
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name', 'organization', 'organization_name',
            'email', 'is_primary', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationEmailCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_create'
        model = models.OrganizationEmail
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationEmailRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationEmailUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_update'
        model = models.OrganizationEmail
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationEmailRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationEmailPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_partial_update'
        model = models.OrganizationEmail
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationEmailRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationEmailEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_enable'
        model = models.OrganizationEmail
        fields = ()
        response_serializer = OrganizationEmailRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationEmailDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_disable'
        model = models.OrganizationEmail
        fields = ()
        response_serializer = OrganizationEmailRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationEmailLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_email_light'
        model = models.OrganizationEmail
        fields = ('id', 'status', 'status_display', 'email', 'is_primary',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# ORGANIZATION PHONE
class OrganizationPhoneSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone'
        model = models.OrganizationPhone
        fields = '__all__'


class OrganizationPhoneListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_list'
        model = models.OrganizationPhone
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name',
            'organization', 'organization_name', 'phone', 'is_primary', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationPhoneRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_retrieve'
        model = models.OrganizationPhone
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name',
            'organization', 'organization_name', 'phone', 'is_primary', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationPhoneCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_create'
        model = models.OrganizationPhone
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationPhoneRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationPhoneUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_update'
        model = models.OrganizationPhone
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationPhoneRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationPhonePartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_partial_update'
        model = models.OrganizationPhone
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationPhoneRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationPhoneEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_enable'
        model = models.OrganizationPhone
        fields = ()
        response_serializer = OrganizationPhoneRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationPhoneDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_disable'
        model = models.OrganizationPhone
        fields = ()
        response_serializer = OrganizationPhoneRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationPhoneLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_phone_light'
        model = models.OrganizationPhone
        fields = ('id', 'status', 'status_display', 'phone', 'is_primary',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# ORGANIZATION SOCIAL PAGE
class OrganizationSocialPageSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page'
        model = models.OrganizationSocialPage
        fields = '__all__'


class OrganizationSocialPageListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_list'
        model = models.OrganizationSocialPage
        fields = (
            'id', 'status', 'status_display', 'social', 'get_social_display',
            'organization', 'organization_name', 'link', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationSocialPageRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_retrieve'
        model = models.OrganizationSocialPage
        fields = (
            'id', 'status', 'status_display', 'social', 'get_social_display',
            'organization', 'organization_name', 'link', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationSocialPageCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_create'
        model = models.OrganizationSocialPage
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationSocialPageRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationSocialPageUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_update'
        model = models.OrganizationSocialPage
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationSocialPageRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationSocialPagePartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_partial_update'
        model = models.OrganizationSocialPage
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OrganizationSocialPageRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OrganizationSocialPageEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_enable'
        model = models.OrganizationSocialPage
        fields = ()
        response_serializer = OrganizationSocialPageRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OrganizationSocialPageDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_disable'
        model = models.OrganizationSocialPage
        fields = ()
        response_serializer = OrganizationSocialPageRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OrganizationSocialPageLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_organization_social_page_light'
        model = models.OrganizationSocialPage
        fields = ('id', 'status', 'status_display', 'link',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# CONTACT ROLE
class ContactRoleSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role'
        model = models.ContactRole
        fields = '__all__'


class ContactRoleListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_list'
        model = models.ContactRole
        fields = ('id', 'status', 'status_display', 'code', 'name', 'ordering')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactRoleRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_retrieve'
        model = models.ContactRole
        fields = ('id', 'status', 'status_display', 'code', 'name', 'ordering')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactRoleCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_create'
        model = models.ContactRole
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactRoleRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactRoleUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_update'
        model = models.ContactRole
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactRoleRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactRolePartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_partial_update'
        model = models.ContactRole
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactRoleRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactRoleEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_enable'
        model = models.ContactRole
        fields = ()
        response_serializer = ContactRoleRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ContactRoleDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_disable'
        model = models.ContactRole
        fields = ()
        response_serializer = ContactRoleRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ContactRoleLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_role_light'
        model = models.ContactRole
        fields = ('id', 'status', 'status_display', 'name',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# CONTACT TITLE
class ContactTitleSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title'
        model = models.ContactTitle
        fields = '__all__'


class ContactTitleListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_list'
        model = models.ContactTitle
        fields = ('code', 'status', 'status_display', 'name', 'abbreviation', 'ordering',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactTitleRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_retrieve'
        model = models.ContactTitle
        fields = ('code', 'status', 'status_display', 'name', 'abbreviation', 'ordering',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactTitleCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_create'
        model = models.ContactTitle
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactTitleRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactTitleUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_update'
        model = models.ContactTitle
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactTitleRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactTitlePartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_partial_update'
        model = models.ContactTitle
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactTitleRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactTitleEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_enable'
        model = models.ContactTitle
        fields = ()
        response_serializer = ContactTitleRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ContactTitleDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_disable'
        model = models.ContactTitle
        fields = ()
        response_serializer = ContactTitleRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ContactTitleLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_title_light'
        model = models.ContactTitle
        fields = ('code', 'status', 'status_display', 'name', 'abbreviation',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# CONTACT
class ContactSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact'
        model = Contact
        fields = '__all__'


class ContactListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    roles = ContactRoleLightSerializer(many=True, read_only=True)

    class Meta:
        ref_name = 'v1_organization_contact_list'
        model = Contact
        fields = (
            'id', 'status', 'status_display', 'code', 'organization', 'organization_name',
            'title', 'title_name', 'language', 'language_name', 'user', 'user_email', 'roles',
            'last_name', 'first_name', 'email', 'mistakes', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    roles = ContactRoleLightSerializer(many=True, read_only=True)

    class Meta:
        ref_name = 'v1_organization_contact_retrieve'
        model = Contact
        fields = (
            'id', 'status', 'status_display', 'code', 'organization', 'organization_name',
            'title', 'title_name', 'user', 'user_email',
            'roles', 'language', 'language_name', 'last_name', 'first_name', 'email', 'mistakes', 'ordering',
            'agree_privacy', 'agree_terms', 'agree_advertising', 'mail_profile_not_completed_sent',
            'avatar', 'note'
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_create'
        model = Contact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_update'
        model = Contact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_partial_update'
        model = Contact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_enable'
        model = Contact
        fields = ()
        response_serializer = ContactRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ContactDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_disable'
        model = Contact
        fields = ()
        response_serializer = ContactRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ContactLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_light'
        model = Contact
        fields = ('id', 'status', 'status_display', 'organization_name', 'full_name')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# OWNER CONTACT
class OwnerContactSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact'
        model = models.OwnerContact
        fields = '__all__'


class OwnerContactListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    roles = ContactRoleLightSerializer(many=True, read_only=True)

    class Meta:
        ref_name = 'v1_organization_owner_contact_list'
        model = models.OwnerContact
        fields = (
            'id', 'status', 'status_display', 'code', 'organization', 'organization_name',
            'title', 'title_name', 'language', 'language_name', 'user', 'user_email', 'roles',
            'last_name', 'first_name', 'email', 'mistakes', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OwnerContactRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    roles = ContactRoleLightSerializer(many=True, read_only=True)

    class Meta:
        ref_name = 'v1_organization_owner_contact_retrieve'
        model = models.OwnerContact
        fields = (
            'id', 'status', 'status_display', 'code', 'organization', 'organization_name',
            'title', 'title_name', 'user', 'user_email',
            'roles', 'language', 'language_name', 'last_name', 'first_name', 'email', 'mistakes', 'ordering',
            'agree_privacy', 'agree_terms', 'agree_advertising', 'mail_profile_not_completed_sent',
            'avatar', 'note'
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OwnerContactCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact_create'
        model = models.OwnerContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OwnerContactRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OwnerContactUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact_update'
        model = models.OwnerContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OwnerContactRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OwnerContactPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact_partial_update'
        model = models.OwnerContact
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = OwnerContactRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class OwnerContactEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact_enable'
        model = models.OwnerContact
        fields = ()
        response_serializer = OwnerContactRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class OwnerContactDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact_disable'
        model = models.OwnerContact
        fields = ()
        response_serializer = OwnerContactRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class OwnerContactLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_owner_contact_light'
        model = models.OwnerContact
        fields = ('id', 'status', 'status_display', 'organization_name', 'full_name')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# CONTACT EMAIL
class ContactEmailSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email'
        model = models.ContactEmail
        fields = '__all__'


class ContactEmailListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_list'
        model = models.ContactEmail
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name',
            'contact', 'contact_full_name', 'contact_last_name', 'contact_first_name',
            'email', 'is_primary', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactEmailRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_retrieve'
        model = models.ContactEmail
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name',
            'contact', 'contact_full_name', 'contact_last_name', 'contact_first_name',
            'email', 'is_primary', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactEmailCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_create'
        model = models.ContactEmail
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactEmailRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactEmailUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_update'
        model = models.ContactEmail
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactEmailRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactEmailPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_partial_update'
        model = models.ContactEmail
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactEmailRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactEmailEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_enable'
        model = models.ContactEmail
        fields = ()
        response_serializer = ContactEmailRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ContactEmailDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_disable'
        model = models.ContactEmail
        fields = ()
        response_serializer = ContactEmailRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ContactEmailLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_email_light'
        model = models.ContactEmail
        fields = ('id', 'status', 'status_display', 'email', 'is_primary',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# CONTACT PHONE
class ContactPhoneSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone'
        model = models.ContactPhone
        fields = '__all__'


class ContactPhoneListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_list'
        model = models.ContactPhone
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name',
            'contact', 'contact_full_name', 'contact_last_name', 'contact_first_name',
            'phone', 'is_primary', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactPhoneRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_retrieve'
        model = models.ContactPhone
        fields = (
            'id', 'status', 'status_display', 'typology', 'typology_name',
            'contact', 'contact_full_name', 'contact_last_name', 'contact_first_name',
            'phone', 'is_primary', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactPhoneCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_create'
        model = models.ContactPhone
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactPhoneRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactPhoneUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_update'
        model = models.ContactPhone
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactPhoneRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactPhonePartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_partial_update'
        model = models.ContactPhone
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactPhoneRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactPhoneEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_enable'
        model = models.ContactPhone
        fields = ()
        response_serializer = ContactPhoneRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ContactPhoneDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_disable'
        model = models.ContactPhone
        fields = ()
        response_serializer = ContactPhoneRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ContactPhoneLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_phone_light'
        model = models.ContactPhone
        fields = ('id', 'status', 'status_display', 'phone', 'is_primary',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# CONTACT SOCIAL ACCOUNT
class ContactSocialAccountSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account'
        model = models.ContactSocialAccount
        fields = '__all__'


class ContactSocialAccountListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_list'
        model = models.ContactSocialAccount
        fields = (
            'id', 'status', 'status_display', 'social', 'get_social_display',
            'contact', 'contact_full_name', 'contact_last_name', 'contact_first_name',
            'account', 'is_primary', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactSocialAccountRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_retrieve'
        model = models.ContactSocialAccount
        fields = (
            'id', 'status', 'status_display', 'social', 'get_social_display',
            'contact', 'contact_full_name', 'contact_last_name', 'contact_first_name',
            'account', 'is_primary', 'ordering',
        )

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactSocialAccountCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_create'
        model = models.ContactSocialAccount
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactSocialAccountRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactSocialAccountUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_update'
        model = models.ContactSocialAccount
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactSocialAccountRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactSocialAccountPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_partial_update'
        model = models.ContactSocialAccount
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = ContactSocialAccountRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class ContactSocialAccountEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_enable'
        model = models.ContactSocialAccount
        fields = ()
        response_serializer = ContactSocialAccountRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class ContactSocialAccountDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_disable'
        model = models.ContactSocialAccount
        fields = ()
        response_serializer = ContactSocialAccountRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class ContactSocialAccountLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_organization_contact_social_account_light'
        model = models.ContactSocialAccount
        fields = ('id', 'status', 'status_display', 'account', 'is_primary',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []
